@@ -40,6 +40,8 @@ ContactsWindow::ContactsWindow(QWidget *parent, Group* group) :
 #endif
 
 #ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5NonComposited, true);
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
     ui->scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     ui->scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 #endif
